==> bonita-server-6.1.2-sources.jar: org/bonitasoft/engine/core/operation/model/builder/impl/SLeftOperandBuilderImpl.java <==
/**
 * Copyright (C) 2011 BonitaSoft S.A.
 * BonitaSoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.core.operation.model.builder.impl;

import org.bonitasoft.engine.core.operation.model.SLeftOperand;
import org.bonitasoft.engine.core.operation.model.builder.SLeftOperandBuilder;
import org.bonitasoft.engine.core.operation.model.impl.SLeftOperandImpl;

/**
 * @author Elias Ricken de Medeiros
 * @author Baptiste Mesta
 */
public class SLeftOperandBuilderImpl implements SLeftOperandBuilder {

    private SLeftOperandImpl leftOperand;

    @Override
    public SLeftOperandBuilder createNewInstance() {
        leftOperand = new SLeftOperandImpl();
        return this;
    }

    @Override
    public SLeftOperandBuilder setExternal(final boolean external) {
        leftOperand.setExternal(external);
        return this;
    }

    @Override
    public SLeftOperandBuilder setName(final String name) {
        leftOperand.setName(name);
        return this;
    }

    @Override
    public SLeftOperand done() {
        return leftOperand;
    }

}

==> bonita-server-6.2.3-sources.jar: org/bonitasoft/engine/core/operation/model/builder/impl/SLeftOperandBuilderImpl.java <==
/**
 * Copyright (C) 2011 BonitaSoft S.A.
 * BonitaSoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.core.operation.model.builder.impl;

import org.bonitasoft.engine.core.operation.model.SLeftOperand;
import org.bonitasoft.engine.core.operation.model.builder.SLeftOperandBuilder;
import org.bonitasoft.engine.core.operation.model.impl.SLeftOperandImpl;

/**
 * @author Elias Ricken de Medeiros
 * @author Baptiste Mesta
 */
public class SLeftOperandBuilderImpl implements SLeftOperandBuilder {

    private final SLeftOperandImpl leftOperand;
    
    public SLeftOperandBuilderImpl(final SLeftOperandImpl leftOperand) {
        super();
        this.leftOperand = leftOperand;
    }

    @Override
    public SLeftOperandBuilder setExternal(final boolean external) {
        leftOperand.setExternal(external);
        return this;
    }

    @Override
    public SLeftOperandBuilder setName(final String name) {
        leftOperand.setName(name);
        return this;
    }

    @Override
    public SLeftOperand done() {
        return leftOperand;
    }

}
